@@ -48,6 +48,11 @@ def make_corepos_menu(request):
                         'url': url('corepos.members'),
                         'perm': 'corepos.members.list',
                     },
+                    {
+                        'title': "Suspensions",
+                        'url': url('corepos.suspensions'),
+                        'perm': 'corepos.suspensions.list',
+                    },
                     {
                         'title': "Member Types",
                         'url': url('corepos.member_types'),
@@ -58,6 +63,11 @@ def make_corepos_menu(request):
                         'url': url('corepos.employees'),
                         'perm': 'corepos.employees.list',
                     },
+                    {
+                        'title': "Users",
+                        'url': url('corepos.users'),
+                        'perm': 'corepos.users.list',
+                    },
                 ],
             },
             {
@@ -84,6 +94,11 @@ def make_corepos_menu(request):
                         'url': url('corepos.scale_items'),
                         'perm': 'corepos.scale_items.list',
                     },
+                    {
+                        'title': "Origins",
+                        'url': url('corepos.origins'),
+                        'perm': 'corepos.origins.list',
+                    },
                     {'type': 'sep'},
                     {
                         'title': "Super Departments",
@@ -132,11 +147,6 @@ def make_corepos_menu(request):
                         'url': url('corepos.purchase_orders'),
                         'perm': 'corepos.purchase_orders.list',
                     },
-                    {
-                        'title': "Origins",
-                        'url': url('corepos.origins'),
-                        'perm': 'corepos.origins.list',
-                    },
                 ],
             },
             {
