@@ -33,6 +33,16 @@ from webhelpers2.html import tags
 from .master import CoreOfficeMasterView
 
 
+def render_member_info(request, custdata, field):
+    meminfo = custdata.member_info
+    if not meminfo:
+        return
+    text = str(meminfo)
+    url = request.route_url('corepos.members.view',
+                            card_number=meminfo.card_number)
+    return tags.link_to(text, url)
+
+
 class CustomerView(CoreOfficeMasterView):
     """
     Base class for customer views.
@@ -127,13 +137,7 @@ class CustomerView(CoreOfficeMasterView):
         return tags.link_to(text, url)
 
     def render_member_info(self, custdata, field):
-        meminfo = custdata.member_info
-        if not meminfo:
-            return
-        text = str(meminfo)
-        url = self.request.route_url('corepos.members.view',
-                                     card_number=meminfo.card_number)
-        return tags.link_to(text, url)
+        return render_member_info(self.request, custdata, field)
 
     def core_office_object_url(self, office_url, customer):
         return core_office_customer_account_url(self.rattail_config,
@@ -162,5 +166,70 @@ class CustomerView(CoreOfficeMasterView):
         return data
 
 
+class SuspensionView(CoreOfficeMasterView):
+    """
+    Master view for legacy customer suspensions.
+    """
+    model_class = corepos.Suspension
+    model_title = "CORE-POS Suspension"
+    model_title_plural = "CORE-POS Suspensions"
+    url_prefix = '/core-pos/suspensions'
+    route_prefix = 'corepos.suspensions'
+
+    labels = {
+        'reason_object': "Reason Code",
+    }
+
+    grid_columns = [
+        'card_number',
+        'type',
+        'memtype1',
+        'memtype2',
+        'suspension_date',
+        'reason',
+        'mail_flag',
+        'discount',
+        'charge_limit',
+        'reason_object',
+    ]
+
+    form_fields = [
+        'card_number',
+        'member_info',
+        'type',
+        'memtype1',
+        'memtype2',
+        'suspension_date',
+        'reason',
+        'mail_flag',
+        'discount',
+        'charge_limit',
+        'reason_object',
+    ]
+
+    def configure_grid(self, g):
+        super(SuspensionView, self).configure_grid(g)
+
+        g.filters['card_number'].default_active = True
+        g.filters['card_number'].default_verb = 'equal'
+
+        g.set_type('charge_limit', 'currency')
+
+        g.set_sort_defaults('card_number')
+
+        g.set_link('card_number')
+
+    def configure_form(self, f):
+        super(SuspensionView, self).configure_form(f)
+
+        f.set_renderer('member_info', self.render_member_info)
+
+        f.set_type('charge_limit', 'currency')
+
+    def render_member_info(self, custdata, field):
+        return render_member_info(self.request, custdata, field)
+
+
 def includeme(config):
     CustomerView.defaults(config)
+    SuspensionView.defaults(config)
