@@ -88,6 +88,7 @@ class MemberView(CoreOfficeMasterView):
         'last_name',
         'other_first_name',
         'other_last_name',
+        'customers',
         'street',
         'city',
         'state',
@@ -98,6 +99,7 @@ class MemberView(CoreOfficeMasterView):
         'ads_ok',
         'dates',
         'barcodes',
+        'suspension',
     ]
 
     def configure_grid(self, g):
@@ -119,10 +121,11 @@ class MemberView(CoreOfficeMasterView):
 
         f.set_renderer('barcodes', self.render_barcodes)
 
-        f.append('customers')
         f.set_readonly('customers')
         f.set_renderer('customers', self.render_customers)
 
+        f.set_renderer('suspension', self.render_suspension)
+
     def render_member_dates(self, member, field):
         if not member.dates:
             return ""
@@ -161,6 +164,16 @@ class MemberView(CoreOfficeMasterView):
             items.append(HTML.tag('li', c=[link]))
         return HTML.tag('ul', c=items)
 
+    def render_suspension(self, member, field):
+        suspension = member.suspension
+        if not suspension:
+            return
+
+        text = str(suspension)
+        url = self.request.route_url('corepos.suspensions.view',
+                                     card_number=suspension.card_number)
+        return tags.link_to(text, url)
+
     def core_office_object_url(self, office_url, member):
         return core_office_customer_account_url(self.rattail_config,
                                                 member.card_number,
