@@ -147,6 +147,9 @@ class ProductView(CoreOfficeMasterView):
         g.filters['upc'].default_active = True
         g.filters['upc'].default_verb = 'contains'
 
+        g.filters['in_use'].default_active = True
+        g.filters['in_use'].default_verb = 'is_true'
+
         g.set_type('cost', 'currency')
         g.set_type('normal_price', 'currency')
 
