@@ -122,11 +122,6 @@ class ProductView(base.ProductView):
 
 def includeme(config):
 
-    # TODO: getting pretty tired of copy/pasting this extra config...
-    config.add_route('products.autocomplete', '/products/autocomplete')
-    config.add_view(base.ProductsAutocomplete, route_name='products.autocomplete',
-                    renderer='json', permission='products.list')
-
     # TODO: getting pretty tired of copy/pasting this extra config...
     config.add_route('products.print_labels', '/products/labels')
     config.add_view(base.print_labels, route_name='products.print_labels',
